from .paths import Caminhos
from .mixer import TocarAudios
# from .main import Run

__version__ = "0.1.1"
